Target

Enum Target 

pub enum Target<T> {
    None,
    AllExceptSingle(T),
    AllExcept(Vec<T>),
    All,
    Only(Vec<T>),
    Single(T),
}
Target indicated which clients should receive some message

Variants



None

Message sent to no client



AllExceptSingle(T)

Message sent to all clients except one



AllExcept(Vec<T>)

Message sent to all clients except for these



All

Message sent to all clients



Only(Vec<T>)

Message sent to only these



Single(T)

Message sent to only this one client

Implementations

Source

impl Target<PeerId>

pub fn apply_targets( &self, clients: impl Iterator<Item = Entity>, mapping: &HashMap<PeerId, Entity>, func: &mut impl FnMut(Entity), )

Calls func on each client entity that matches the provided target

Source

impl<T> Target<T>
where T: PartialEq + Eq + Hash + Clone + Copy,

pub fn is_empty(&self) -> bool

Returns true if the target is empty

pub fn from_exclude(client_ids: impl IntoIterator<Item = T>) -> Target<T>

pub fn targets(&self, client_id: &T) -> bool

Return true if we should replicate to the specified client