Module core

Module core 

Modules

buffer_pool
Bounded recycling for split mutable byte-buffer allocations. Bounded recycling for split [BytesMut] allocations.
confirmed_history
Provides ConfirmedHistory for authoritative remote component states.
ecs_utils
Low-level ECS helpers shared by type-erased systems. Low-level ECS access helpers shared by Lightyear crates.
frame_interpolation
Shared marker and history components used by frame interpolation.
history_buffer
Provides HistoryBuffer for storing and managing historical state.
id
Provides types for network identifiers, such as PeerId and NetId. Module to handle the various possible ClientIds
interpolation
network
Provides core network-related types and traits.
plugin
Defines core plugin structures and related utilities.
prediction
prelude
Commonly used items from the lightyear_core crate.
tick
Defines the Tick type and related systems for managing discrete time steps.
time
Utilities for time management, including interpolation and synchronization. This module contains some helper functions to compute the difference between two times.
timeline
Defines Timeline for managing different views of time (local, network).