pub enum PeerId {
Entity(u64),
Raw(SocketAddr),
Netcode(u64),
Steam(u64),
Local(u64),
Server,
}Variants
Entity(u64)
Raw(SocketAddr)
A raw connection where the IO Link is used to associate a long-term id. The id is the SocketAddr of the link.
Netcode(u64)
A client id that is unique between netcode connections
Steam(u64)
The client id of a steam user
Local(u64)
A local client to use when running in HostServer mode
Server
Refers to the server
Implementations