pub struct TickInstant {
pub value: FixedU64<UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>,
}Expand description
Uniquely identify a instant across all timelines
Fields
value: FixedU64<UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>Implementations
Sourceimpl TickInstant
impl TickInstant
pub const fn lit(src: &str) -> TickInstant
pub const fn zero() -> TickInstant
pub fn tick(&self) -> Tick
Sourcepub fn from_tick_and_overstep(tick: Tick, overstep: Overstep) -> TickInstant
pub fn from_tick_and_overstep(tick: Tick, overstep: Overstep) -> TickInstant
Construct a TickInstant from an integer tick and a fractional overstep.
tick is the whole tick count, and overstep is the fraction towards
the next tick in the range [0, 1).
Sourcepub fn as_duration(&self, tick_duration: Duration) -> Duration
pub fn as_duration(&self, tick_duration: Duration) -> Duration
Convert this instant to a duration
pub fn as_time_delta(&self, tick_duration: Duration) -> TimeDelta
Sourcepub fn from_duration(duration: Duration, tick_duration: Duration) -> TickInstant
pub fn from_duration(duration: Duration, tick_duration: Duration) -> TickInstant
Convert a duration to a TickInstant
pub fn from_time_delta(delta: TimeDelta, tick_duration: Duration) -> TickInstant