pub struct FrameInterpolationPlugin<C> { /* private fields */ }Available on crate feature
frame_interpolation only.Expand description
Bevy plugin to enable visual interpolation for a specific component C.
This plugin adds systems to store the state of component C at each FixedUpdate tick
and then interpolate between the previous and current tick’s state during the PostUpdate
schedule, using the Time<Fixed>::overstep_percentage. This helps smooth
visuals when the rendering framerate doesn’t align perfectly with the fixed simulation rate.
To use this, the component C must implement Component<Mutability=Mutable> + Clone and have an
interpolation function registered in the InterpolationRegistry.
You also need to add the FrameInterpolate<C> component to entities
for which you want to enable this visual interpolation.