pub struct Ordinal<N, NE, E, SE, S, SW, W, NW> {
pub north: N,
pub north_east: NE,
pub east: E,
pub south_east: SE,
pub south: S,
pub south_west: SW,
pub west: W,
pub north_west: NW,
}Available on crate feature
input_bei and (crate features input_bei or input_native or leafwing) only.Expand description
A preset to 8 map buttons as 2-dimensional input.
Fields
north: Nnorth_east: NEeast: Esouth_east: SEsouth: Ssouth_west: SWwest: Wnorth_west: NWImplementations
Sourceimpl Ordinal<Binding, Binding, Binding, Binding, Binding, Binding, Binding, Binding>
impl Ordinal<Binding, Binding, Binding, Binding, Binding, Binding, Binding, Binding>
Sourcepub fn numpad() -> Ordinal<Binding, Binding, Binding, Binding, Binding, Binding, Binding, Binding>
pub fn numpad() -> Ordinal<Binding, Binding, Binding, Binding, Binding, Binding, Binding, Binding>
Maps numpad keys as 2-dimensional input.
Sourcepub fn new(
north: impl Into<Binding>,
north_east: impl Into<Binding>,
east: impl Into<Binding>,
south_east: impl Into<Binding>,
south: impl Into<Binding>,
south_west: impl Into<Binding>,
west: impl Into<Binding>,
north_west: impl Into<Binding>,
) -> Ordinal<Binding, Binding, Binding, Binding, Binding, Binding, Binding, Binding>
pub fn new( north: impl Into<Binding>, north_east: impl Into<Binding>, east: impl Into<Binding>, south_east: impl Into<Binding>, south: impl Into<Binding>, south_west: impl Into<Binding>, west: impl Into<Binding>, north_west: impl Into<Binding>, ) -> Ordinal<Binding, Binding, Binding, Binding, Binding, Binding, Binding, Binding>
Maps 8 bindings as 2-dimensional input.
NW N NE
🡴 🡱 🡵
W 🡰 · 🡲 E
🡷 🡳 🡶
SW S SETrait Implementations
impl<N, NE, E, SE, S, SW, W, NW> Copy for Ordinal<N, NE, E, SE, S, SW, W, NW>
Sourceimpl<N, NE, E, SE, S, SW, W, NW> SpawnableList<BindingOf> for Ordinal<N, NE, E, SE, S, SW, W, NW>
impl<N, NE, E, SE, S, SW, W, NW> SpawnableList<BindingOf> for Ordinal<N, NE, E, SE, S, SW, W, NW>
Sourcefn spawn(
this: MovingPtr<'_, Ordinal<N, NE, E, SE, S, SW, W, NW>>,
world: &mut World,
entity: Entity,
)
fn spawn( this: MovingPtr<'_, Ordinal<N, NE, E, SE, S, SW, W, NW>>, world: &mut World, entity: Entity, )
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
Returns a size hint, which is used to reserve space for this list in a
RelationshipTarget. This should be
less than or equal to the actual size of the list. When in doubt, just use 0.Auto Trait Implementations
impl<N, NE, E, SE, S, SW, W, NW> Freeze for Ordinal<N, NE, E, SE, S, SW, W, NW>
impl<N, NE, E, SE, S, SW, W, NW> RefUnwindSafe for Ordinal<N, NE, E, SE, S, SW, W, NW>where
N: RefUnwindSafe,
NE: RefUnwindSafe,
E: RefUnwindSafe,
SE: RefUnwindSafe,
S: RefUnwindSafe,
SW: RefUnwindSafe,
W: RefUnwindSafe,
NW: RefUnwindSafe,
impl<N, NE, E, SE, S, SW, W, NW> Send for Ordinal<N, NE, E, SE, S, SW, W, NW>
impl<N, NE, E, SE, S, SW, W, NW> Sync for Ordinal<N, NE, E, SE, S, SW, W, NW>
impl<N, NE, E, SE, S, SW, W, NW> Unpin for Ordinal<N, NE, E, SE, S, SW, W, NW>
impl<N, NE, E, SE, S, SW, W, NW> UnsafeUnpin for Ordinal<N, NE, E, SE, S, SW, W, NW>where
N: UnsafeUnpin,
NE: UnsafeUnpin,
E: UnsafeUnpin,
SE: UnsafeUnpin,
S: UnsafeUnpin,
SW: UnsafeUnpin,
W: UnsafeUnpin,
NW: UnsafeUnpin,
impl<N, NE, E, SE, S, SW, W, NW> UnwindSafe for Ordinal<N, NE, E, SE, S, SW, W, NW>where
N: UnwindSafe,
NE: UnwindSafe,
E: UnwindSafe,
SE: UnwindSafe,
S: UnwindSafe,
SW: UnwindSafe,
W: UnwindSafe,
NW: UnwindSafe,