InterpolationSet

Type Alias InterpolationSet 

pub type InterpolationSet = InterpolationSystems;
👎Deprecated:

Use InterpolationSystems instead

Available on crate feature interpolation only.

Aliased Type

pub enum InterpolationSet {
    Sync,
    Prepare,
    Interpolate,
    All,
}

Variants



Sync

Sync components from the confirmed to the interpolated entity, and insert the ConfirmedHistory



Prepare

Update component history (add new values from confirmed updates and pop values that are older than interpolation)

This can be in Update since we use the confirmed.tick to add values to the history, which is independent from the local tick.



Interpolate

Interpolate between last 2 server states. Has to be overridden if InterpolationConfig.custom_interpolation_logic is set to true



All

SystemSet encompassing all other interpolation sets