Module link

Module link 

Modules

prelude
server
Server-side link relationships.

Structs

Link
Transport-neutral byte stream between two peers.
LinkConditioner
Generic receive-side packet conditioner.
LinkMtu
The minimum and currently available maximum payload size of a link.
LinkPlugin
Bevy plugin that installs link lifecycle and receive-buffer systems.
LinkReceiver
Receive-side payload queue for a Link.
LinkSender
Send-side payload queue for a Link.
LinkStart
Entity event requesting that a transport start establishing a Link.
LinkStats
Transport-observed statistics for a Link.
Linked
Marker component for an established link.
Linking
Marker component for a link whose transport connection is being established.
MtuTooSmall
Error returned when a current MTU is smaller than a link’s stable minimum MTU.
Unlink
Entity event requesting that a transport terminate a Link.
Unlinked
Marker component for a link that is not connected.

Enums

LinkReceiveSystems
System sets that make up LinkSystems::Receive.
LinkState
Current lifecycle state of a Link.
LinkSystems
System sets for Link-related operations.
UnlinkReason
Why a Link was unlinked via Unlink or Unlinked.

Constants

DEFAULT_MTU
Conservative default maximum payload size for a link.

Functions

recv_payload_from_bytes
Converts an immutable transport payload into Lightyear’s mutable receive payload.

Type Aliases

LinkReceiveSetDeprecated
Deprecated alias for LinkReceiveSystems.
LinkSetDeprecated
Deprecated alias for LinkSystems.
RecvLinkConditioner
Packet conditioner used for inbound RecvPayload values.
RecvPayload
Mutable byte payload received from a transport.
SendPayload
Opaque byte payload queued for a transport to send.