pub struct ServerLinkPlugin;Expand description
Plugin that installs server/link relationship support.
The plugin ensures LinkPlugin is present and adds the observer that reacts to Unlinked
on server entities by unlinking/despawning their child links. Transport crates that expose a
multi-client server endpoint should add this plugin before scheduling their server IO systems.