pub struct LinkConditioner<P>where
P: Eq,{
pub time_queue: ReadyBuffer<Instant, P>,
/* private fields */
}Expand description
Generic receive-side packet conditioner.
LinkConditioner delays and drops payloads according to a LinkConditionerConfig.
Fields
time_queue: ReadyBuffer<Instant, P>Payloads waiting for their simulated delivery time.
The key is the delivery Instant. Once that instant is less than or equal to the instant
passed to the polling code, the payload is ready to be moved into the receive buffer.
This field is public for tests and low-level integrations, but normal link users should
interact through crate::LinkReceiver.
Implementations
Sourceimpl<P> LinkConditioner<P>where
P: Eq,
impl<P> LinkConditioner<P>where
P: Eq,
Sourcepub fn new(config: LinkConditionerConfig) -> LinkConditioner<P>
pub fn new(config: LinkConditionerConfig) -> LinkConditioner<P>
Creates an empty conditioner using config.