pub struct DeterministicPredicted {
pub skip_despawn: bool,
pub enable_rollback_after: u8,
}prediction only.Expand description
Marker component used to indicate this entity is predicted (it has a PredictionHistory), but it won’t check for rollback from state updates.
This can be used to mark predicted non-networked entities in deterministic replication, or to stop a state-replicated entity from being able to trigger rollbacks from state mismatch.
This entity will still get rolled back to its predicted history when a rollback happens.
Fields
skip_despawn: boolAfter spawning a DeterministicPredicted entity, any rollback that happens shortly after might despawn the entity (since it didn’t exist at the start of rollback) or remove its components.
If the entity was spawned in a deterministic manner (for instance with a ‘Shoot’ input), then we want the entity to be despawned as it will get re-created during rollback. But if the entity was spawned as a one-off event (for example replicated by the server upon connection), we don’t want the entity to be affected by rollbacks for a short period after being spawned.
enable_rollback_after: u8For entities where skip_despawn is True, after how many ticks do we start enabling back rollbacks?