InputTimeline

Struct InputTimeline 

pub struct InputTimeline(pub Timeline<InputTimelineConfig>);
Available on crate feature client only.
Timeline that is used to keep track of when the client should buffer inputs.

This timeline is synced with the server timeline, and is the main driving timeline: any speed adjustments applied to this timeline will also be applied to the Time<Virtual> timeline. (and will therefore affect how fast the FixedUpdate loop runs, and how ticks are incremented)

This timeline is updated in PostUpdate; it CANNOT be used to get accurate tick in PreUpdate or Update; use LocalTimeline instead.

Tuple Fields

0: Timeline<InputTimelineConfig>