pub struct ActionEvents(/* private fields */);input_bei and (crate features input_bei or input_native or leafwing) only.Expand description
Bitset with events caused by state transitions of TriggerState.
During EnhancedInputSystems::Apply, events that correspond to bitflags will be triggered.
You can use this component directly in systems or react on corresponding events in observers.
Table of state transitions:
The meaning of each kind depends on the assigned InputConditions. The events are
triggered in the action evaluation order.
Implementations
Sourceimpl ActionEvents
impl ActionEvents
pub const STARTED: ActionEvents = Self::START
Replaced by START
pub const FIRED: ActionEvents = Self::FIRE
Replaced by FIRE
pub const CANCELLED: ActionEvents = Self::CANCEL
Replaced by CANCEL
pub const COMPLETED: ActionEvents = Self::COMPLETE
Replaced by COMPLETE
Sourceimpl ActionEvents
impl ActionEvents
Sourcepub const START: ActionEvents
pub const START: ActionEvents
Corresponds to Start.
Sourcepub const ONGOING: ActionEvents
pub const ONGOING: ActionEvents
Corresponds to Ongoing.
Sourcepub const FIRE: ActionEvents
pub const FIRE: ActionEvents
Corresponds to Fire.
Sourcepub const CANCEL: ActionEvents
pub const CANCEL: ActionEvents
Corresponds to Cancel.
Sourcepub const COMPLETE: ActionEvents
pub const COMPLETE: ActionEvents
Corresponds to Complete.
Sourceimpl ActionEvents
impl ActionEvents
Sourcepub const fn empty() -> ActionEvents
pub const fn empty() -> ActionEvents
Get a flags value with all bits unset.
Sourcepub const fn all() -> ActionEvents
pub const fn all() -> ActionEvents
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ActionEvents>
pub const fn from_bits(bits: u8) -> Option<ActionEvents>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ActionEvents
pub const fn from_bits_truncate(bits: u8) -> ActionEvents
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ActionEvents
pub const fn from_bits_retain(bits: u8) -> ActionEvents
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ActionEvents>
pub fn from_name(name: &str) -> Option<ActionEvents>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ActionEvents) -> bool
pub const fn intersects(&self, other: ActionEvents) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ActionEvents) -> bool
pub const fn contains(&self, other: ActionEvents) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ActionEvents)
pub fn insert(&mut self, other: ActionEvents)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ActionEvents)
pub fn remove(&mut self, other: ActionEvents)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ActionEvents)
pub fn toggle(&mut self, other: ActionEvents)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ActionEvents, value: bool)
pub fn set(&mut self, other: ActionEvents, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ActionEvents) -> ActionEvents
pub const fn intersection(self, other: ActionEvents) -> ActionEvents
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ActionEvents) -> ActionEvents
pub const fn union(self, other: ActionEvents) -> ActionEvents
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ActionEvents) -> ActionEvents
pub const fn difference(self, other: ActionEvents) -> ActionEvents
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ActionEvents) -> ActionEvents
pub const fn symmetric_difference(self, other: ActionEvents) -> ActionEvents
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ActionEvents
pub const fn complement(self) -> ActionEvents
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ActionEvents
impl ActionEvents
Sourcepub const fn iter(&self) -> Iter<ActionEvents>
pub const fn iter(&self) -> Iter<ActionEvents>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ActionEvents>
pub const fn iter_names(&self) -> IterNames<ActionEvents>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ActionEvents
impl ActionEvents
Sourcepub fn new(previous: TriggerState, current: TriggerState) -> ActionEvents
pub fn new(previous: TriggerState, current: TriggerState) -> ActionEvents
Creates a new instance based on state transition.