pub struct ActionState<A>(pub A);Available on crate feature
input_native and (crate features input_bei or input_native or leafwing) only.Expand description
The component that will store the current status of the action for the entity
Note that your action HAS to implement MapEntities and Default.
The Default value should be when no actions/inputs are active.
It is important to distinguish between “no input” (e.g. no keys pressed) and “input not received” (e.g. network packet loss).
Tuple Fields
0: ATrait Implementations
Sourceimpl<A> ActionStateQueryData for ActionState<A>
impl<A> ActionStateQueryData for ActionState<A>
type Mut = &'static mut ActionState<A>
type MutItemInner<'w> = &'w mut ActionState<A>
type Main = ActionState<A>
type Bundle = ActionState<A>
fn as_read_only<'a, 'w, 's>(
state: &'a <<ActionState<A> as ActionStateQueryData>::Mut as QueryData>::Item<'w, 's>,
) -> <<<ActionState<A> as ActionStateQueryData>::Mut as QueryData>::ReadOnly as QueryData>::Item<'a, 's>where
'w: 'a,
fn into_inner<'w, 's>( mut_item: <<ActionState<A> as ActionStateQueryData>::Mut as QueryData>::Item<'w, 's>, ) -> <ActionState<A> as ActionStateQueryData>::MutItemInner<'w>
fn as_mut( bundle: &mut <ActionState<A> as ActionStateQueryData>::Bundle, ) -> <ActionState<A> as ActionStateQueryData>::MutItemInner<'_>
fn base_value() -> <ActionState<A> as ActionStateQueryData>::Bundle
Sourceimpl<A> Clone for ActionState<A>where
A: Clone,
impl<A> Clone for ActionState<A>where
A: Clone,
Sourcefn clone(&self) -> ActionState<A>
fn clone(&self) -> ActionState<A>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<A> Component for ActionState<A>
impl<A> Component for ActionState<A>
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcetype Mutability = Mutable
type Mutability = Mutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have
Component<Mutability = Mutable>,
while immutable components will instead have Component<Mutability = Immutable>. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Registers required components. Read more
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<ActionState<A>>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<ActionState<A>>>
Returns
ComponentRelationshipAccessor required for working with relationships in dynamic contexts. Read moreSourcefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_replace() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_replace() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
Maps the entities on this component using the given
EntityMapper. This is used to remap entities in contexts like scenes and entity cloning.
When deriving Component, this is populated by annotating fields containing entities with #[entities] Read moreSourceimpl<A> Debug for ActionState<A>where
A: Debug,
impl<A> Debug for ActionState<A>where
A: Debug,
Sourceimpl<A> Default for ActionState<A>where
A: Default,
impl<A> Default for ActionState<A>where
A: Default,
Sourcefn default() -> ActionState<A>
fn default() -> ActionState<A>
Returns the “default value” for a type. Read more
Sourceimpl<A> Deref for ActionState<A>
impl<A> Deref for ActionState<A>
Sourceimpl<A> DerefMut for ActionState<A>
impl<A> DerefMut for ActionState<A>
Sourceimpl<'de, A> Deserialize<'de> for ActionState<A>where
A: Deserialize<'de>,
impl<'de, A> Deserialize<'de> for ActionState<A>where
A: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ActionState<A>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ActionState<A>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<A> From<&ActionState<A>> for Compressed<A>where
A: Clone,
impl<A> From<&ActionState<A>> for Compressed<A>where
A: Clone,
Sourcefn from(value: &ActionState<A>) -> Compressed<A>
fn from(value: &ActionState<A>) -> Compressed<A>
Converts to this type from the input type.
Sourceimpl<A> FromReflect for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<A> FromReflect for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
Sourcefn from_reflect(
reflect: &(dyn PartialReflect + 'static),
) -> Option<ActionState<A>>
fn from_reflect( reflect: &(dyn PartialReflect + 'static), ) -> Option<ActionState<A>>
Constructs a concrete instance of
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Attempts to downcast the given value to
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl<A> GetTypeRegistration for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<A> GetTypeRegistration for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
Returns the default
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers other types needed by this type. Read more
Sourceimpl<A> InputSnapshot for ActionState<A>
impl<A> InputSnapshot for ActionState<A>
Sourcefn decay_tick(&mut self, tick_duration: Duration)
fn decay_tick(&mut self, tick_duration: Duration)
Predict the next snapshot after 1 tick. Read more
Sourceimpl<A> MapEntities for ActionState<A>where
A: MapEntities,
impl<A> MapEntities for ActionState<A>where
A: MapEntities,
Sourcefn map_entities<E>(&mut self, entity_mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(&mut self, entity_mapper: &mut E)where
E: EntityMapper,
Sourceimpl<A> PartialEq for ActionState<A>where
A: PartialEq,
impl<A> PartialEq for ActionState<A>where
A: PartialEq,
Sourcefn eq(&self, other: &ActionState<A>) -> bool
fn eq(&self, other: &ActionState<A>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<A> PartialReflect for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<A> PartialReflect for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn try_apply(
&mut self,
value: &(dyn PartialReflect + 'static),
) -> Result<(), ApplyError>
fn try_apply( &mut self, value: &(dyn PartialReflect + 'static), ) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Returns a zero-sized enumeration of “kinds” of type. Read more
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Returns an immutable enumeration of “kinds” of type. Read more
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Returns a mutable enumeration of “kinds” of type. Read more
Sourcefn reflect_owned(self: Box<ActionState<A>>) -> ReflectOwned
fn reflect_owned(self: Box<ActionState<A>>) -> ReflectOwned
Returns an owned enumeration of “kinds” of type. Read more
Sourcefn try_into_reflect(
self: Box<ActionState<A>>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<ActionState<A>>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Attempts to cast this type to a boxed, fully-reflected value.
Sourcefn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
Attempts to cast this type to a fully-reflected value.
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
Attempts to cast this type to a mutable, fully-reflected value.
Sourcefn into_partial_reflect(self: Box<ActionState<A>>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<ActionState<A>>) -> Box<dyn PartialReflect>
Casts this type to a boxed, reflected value. Read more
Sourcefn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
Casts this type to a reflected value. Read more
Sourcefn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
Casts this type to a mutable, reflected value. Read more
Sourcefn reflect_partial_eq(
&self,
value: &(dyn PartialReflect + 'static),
) -> Option<bool>
fn reflect_partial_eq( &self, value: &(dyn PartialReflect + 'static), ) -> Option<bool>
Returns a “partial equality” comparison result. Read more
Sourcefn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Attempts to clone
Self using reflection. Read moreSourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Applies a reflected value to this value. Read more
Sourcefn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
Sourcefn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
For a type implementing
PartialReflect, combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
ReflectCloneError if the downcast fails. Read moreSourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Returns a hash of the value (which includes the type). Read more
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Debug formatter for the value. Read more
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Indicates whether or not this type is a dynamic type. Read more
Sourceimpl<A> Reflect for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<A> Reflect for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
Sourcefn into_any(self: Box<ActionState<A>>) -> Box<dyn Any>
fn into_any(self: Box<ActionState<A>>) -> Box<dyn Any>
Returns the value as a
Box<dyn Any>. Read moreSourcefn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
Returns the value as a
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<ActionState<A>>) -> Box<dyn Reflect>
fn into_reflect(self: Box<ActionState<A>>) -> Box<dyn Reflect>
Casts this type to a boxed, fully-reflected value.
Sourcefn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Casts this type to a fully-reflected value.
Sourcefn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Casts this type to a mutable, fully-reflected value.
Sourceimpl<A> Serialize for ActionState<A>where
A: Serialize,
impl<A> Serialize for ActionState<A>where
A: Serialize,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<A> StructuralPartialEq for ActionState<A>where
A: PartialEq,
Sourceimpl<A> TupleStruct for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<A> TupleStruct for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
Sourcefn field(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
fn field(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
Returns a reference to the value of the field with index
index as a
&dyn Reflect.Sourcefn field_mut(
&mut self,
index: usize,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_mut( &mut self, index: usize, ) -> Option<&mut (dyn PartialReflect + 'static)>
Returns a mutable reference to the value of the field with index
index
as a &mut dyn Reflect.Sourcefn iter_fields(&self) -> TupleStructFieldIter<'_>
fn iter_fields(&self) -> TupleStructFieldIter<'_>
Returns an iterator over the values of the tuple struct’s fields.
Sourcefn to_dynamic_tuple_struct(&self) -> DynamicTupleStruct
fn to_dynamic_tuple_struct(&self) -> DynamicTupleStruct
Creates a new
DynamicTupleStruct from this tuple struct.Sourcefn get_represented_tuple_struct_info(&self) -> Option<&'static TupleStructInfo>
fn get_represented_tuple_struct_info(&self) -> Option<&'static TupleStructInfo>
Will return
None if TypeInfo is not available.Sourceimpl<A> TypePath for ActionState<A>
impl<A> TypePath for ActionState<A>
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl<A> Typed for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,
impl<A> Typed for ActionState<A>where
ActionState<A>: Any + Send + Sync,
A: TypePath + FromReflect + MaybeTyped + RegisterForReflection,