RootCertStore

Struct RootCertStore 

pub struct RootCertStore {
    pub roots: Vec<TrustAnchor<'static>>,
}
Available on crate feature websocket only.
A container for root certificates able to provide a root-of-trust for connection authentication.

Fields

roots: Vec<TrustAnchor<'static>>

The list of roots.

Implementations

Source

impl RootCertStore

pub fn empty() -> RootCertStore

Make a new, empty RootCertStore.

pub fn add_parsable_certificates<'a>( &mut self, der_certs: impl IntoIterator<Item = CertificateDer<'a>>, ) -> (usize, usize)

Parse the given DER-encoded certificates and add all that can be parsed in a best-effort fashion.

This is because large collections of root certificates often include ancient or syntactically invalid certificates.

Returns the number of certificates added, and the number that were ignored.

pub fn add(&mut self, der: CertificateDer<'_>) -> Result<(), Error>

Add a single DER-encoded certificate to the store.

This is suitable for a small set of root certificates that are expected to parse successfully. For large collections of roots (for example from a system store) it is expected that some of them might not be valid according to the rules rustls implements. As long as a relatively limited number of certificates are affected, this should not be a cause for concern. Use RootCertStore::add_parsable_certificates in order to add as many valid roots as possible and to understand how many certificates have been diagnosed as malformed.

pub fn subjects(&self) -> Vec<DistinguishedName>

Return the DER encoded DistinguishedName of each trust anchor subject in the root cert store.

Each DistinguishedName will be a DER-encoded X.500 distinguished name, per RFC 5280 A.1, including the outer SEQUENCE.

pub fn is_empty(&self) -> bool

Return true if there are no certificates.

pub fn len(&self) -> usize

Say how many certificates are in the container.