pub struct ServerInputPlugin<S> {
pub rebroadcast_inputs: bool,
pub marker: PhantomData<S>,
}Available on crate feature
server and (crate features input_bei or input_native or leafwing) only.Expand description
Server-side plugin that receives input messages from clients and applies
them to InputBuffer components.
If rebroadcast_inputs is enabled, the server also forwards input messages
to other clients so they can use them for remote-player prediction.
Fields
rebroadcast_inputs: boolmarker: PhantomData<S>Trait Implementations
Sourceimpl<S> Default for ServerInputPlugin<S>
impl<S> Default for ServerInputPlugin<S>
Sourcefn default() -> ServerInputPlugin<S>
fn default() -> ServerInputPlugin<S>
Returns the “default value” for a type. Read more
Sourceimpl<S> Plugin for ServerInputPlugin<S>where
S: ActionStateSequence + MapEntities,
impl<S> Plugin for ServerInputPlugin<S>where
S: ActionStateSequence + MapEntities,
Sourcefn ready(&self, _app: &App) -> bool
fn ready(&self, _app: &App) -> bool
Has the plugin finished its setup? This can be useful for plugins that need something
asynchronous to happen before they can finish their setup, like the initialization of a renderer.
Once the plugin is ready,
finish should be called.Sourcefn finish(&self, _app: &mut App)
fn finish(&self, _app: &mut App)
Finish adding this plugin to the
App, once all plugins registered are ready. This can
be useful for plugins that depends on another plugin asynchronous setup, like the renderer.Sourcefn cleanup(&self, _app: &mut App)
fn cleanup(&self, _app: &mut App)
Runs after all plugins are built and finished, but before the app schedule is executed.
This can be useful if you have some resource that other plugins need during their build step,
but after build you want to remove it and send it to another thread.