pub enum AuthSessionValidateError {
UserNotConnectedToSteam,
NoLicenseOrExpired,
VACBanned,
LoggedInElseWhere,
VACCheckTimedOut,
AuthTicketCancelled,
AuthTicketInvalidAlreadyUsed,
AuthTicketInvalid,
PublisherIssuedBan,
}Available on crate feature
steam only.Expand description
Errors from ValidateAuthTicketResponse
Variants
UserNotConnectedToSteam
The user in question is not connected to steam
NoLicenseOrExpired
The license has expired
VACBanned
The user is VAC banned from the game
LoggedInElseWhere
The user has logged in elsewhere and the session has been disconnected
VACCheckTimedOut
VAC has been unable to perform anti-cheat checks on this user
AuthTicketCancelled
The ticket has been cancelled by the issuer
AuthTicketInvalidAlreadyUsed
The ticket has already been used
AuthTicketInvalid
The ticket is not from a user instance currently connected to steam
PublisherIssuedBan
The user is banned from the game (not VAC)