ComponentRegistration

Struct ComponentRegistration 

pub struct ComponentRegistration<'a, C> {
    pub app: &'a mut App,
    /* private fields */
}
Available on crate feature replication only.

Fields

app: &'a mut App

Implementations

Source

impl<C> ComponentRegistration<'_, C>

pub fn new(app: &mut App) -> ComponentRegistration<'_, C>

pub fn add_map_entities(self) -> ComponentRegistration<'_, C>
where C: Clone + MapEntities + 'static,

Specify that the component contains entities which should be mapped from the remote world to the local world upon deserialization using the component’s MapEntities implementation.

pub fn add_component_map_entities(self) -> ComponentRegistration<'_, C>
where C: Clone + Component + 'static,

Similar to add_map_entities, but uses the Component::map_entities function instead of MapEntities::map_entities

pub fn with_replication_config( self, config: ComponentReplicationConfig, ) -> ComponentRegistration<'_, C>
where C: Component, <C as Component>::Mutability: GetWriteFns<C>,

pub fn add_delta_compression<Delta>(self) -> ComponentRegistration<'_, C>
where C: Component<Mutability = Mutable> + PartialEq + Diffable<Delta>, Delta: Serialize + DeserializeOwned + Message,

Enable delta compression when serializing this component

Source

impl<C> ComponentRegistration<'_, C>
where C: Debug,

pub fn add_default_hash(self) -> ComponentRegistration<'_, C>
where C: Hash + Component,

Add a hash function for this component using the core::hash::Hash trait implementation.

This will be used to compute a checksum for determinism checks.

pub fn add_custom_hash( self, f: fn(&C, &mut SeaHasher), ) -> ComponentRegistration<'_, C>
where C: Component,

Add a hash function for this component using the core::hash::Hash trait implementation.

This will be used to compute a checksum for determinism checks.