pub struct MetricsRegistry { /* private fields */ }Available on crate feature
metrics only.Expand description
Tracks all metrics in the current process.
You may never need to interact with this, unless you want to call
set_global_recorder manually and provide a
clone of that same registry to the RegistryPlugin.
Implementations
Sourceimpl MetricsRegistry
impl MetricsRegistry
pub fn fetch_metric_value(&self, key: &CompositeKey) -> Option<f64>
pub fn fetch_global_metric_value(key: &CompositeKey) -> Option<f64>
Available on crate feature
std only.Sourceimpl MetricsRegistry
impl MetricsRegistry
Sourcepub fn new() -> MetricsRegistry
pub fn new() -> MetricsRegistry
Create an empty registry.
pub fn reset_metric(&self, key: &CompositeKey) -> Option<()>
Sourcepub fn get_counter_value(&self, key: &Key) -> Option<f64>
pub fn get_counter_value(&self, key: &Key) -> Option<f64>
Get the value of a Counter identified by a string
pub fn get_gauge_value(&self, key: &Key) -> Option<f64>
pub fn get_histogram_mean(&self, key: &Key) -> Option<f64>
pub fn get_or_create_counter(&self, key: &Key) -> Arc<Atomic<u64>> ⓘ
pub fn get_or_create_gauge(&self, key: &Key) -> Arc<Atomic<u64>> ⓘ
pub fn get_or_create_histogram(&self, key: &Key) -> Arc<AtomicBucket<f64>> ⓘ
Sourcepub fn all_metrics(&self) -> Vec<SearchResult>
pub fn all_metrics(&self) -> Vec<SearchResult>
Get a search result for every registered metric.
Sourcepub fn clear_atomic_buckets(&self)
pub fn clear_atomic_buckets(&self)
Clear all atomic buckets used for storing histogram data.