pub struct PingManager {
pub rtt_estimator_ewma: RttEstimatorEwma,
pub pongs_recv: u32,
/* private fields */
}Expand description
The PingManager is responsible for sending regular pings to the remote machine,
and monitor pongs in order to estimate statistics (rtt, jitter) about the connection.
Fields
rtt_estimator_ewma: RttEstimatorEwmaEstimator used to compute RTT/Jitter from pongs and packet acknowledgements.
pongs_recv: u32The number of pongs we have received
Implementations
Sourceimpl PingManager
impl PingManager
pub fn new(config: PingConfig) -> PingManager
Sourcepub fn latency_samples_recv(&self) -> u32
pub fn latency_samples_recv(&self) -> u32
Return the number of RTT samples used to estimate latency.
Sourcepub fn process_packet_rtt_sample(&mut self, rtt_sample: Duration)
pub fn process_packet_rtt_sample(&mut self, rtt_sample: Duration)
Process an RTT sample measured from an ordinary packet acknowledgement.