pub struct PreSpawned {
pub hash: Option<u64>,
pub user_salt: Option<u64>,
pub receiver: Option<Entity>,
}replication only.Expand description
Added to indicate the client has prespawned the predicted version of this entity.
The server should spawn a similar component and replicate it to the client, when the client receive that replicated entity, it will try to match it with the prespawned entity using the hash value.
Prespawned entities must be spawned in the FixedMain schedule.
// Default hashing implementation: (tick + components)
PreSpawned::default();
// Default hashing implementation with additional user-provided salt:
let client_id: u64 = 12345;
PreSpawned::default_with_salt(client_id);
// User-provided custom hash
let custom_hash: u64 = 1;
PreSpawned::new(1);Fields
hash: Option<u64>The hash that will identify the spawned entity By default, if the hash is not set, it will be generated from the entity’s archetype (list of components) and spawn tick Otherwise you can manually set it to a value that will be the same on both the client and server
user_salt: Option<u64>An optional extra value that will be passed to the hasher as part of the default hashing algorithm
Since the default hash uses the tick and components, a useful addition is the client id, to distinguish between bullets spawned on the same tick, but by different players.
receiver: Option<Entity>Receiver entity that is prespawning this entity.
If None, then we will use the entity that has a PreSpawnedReceiver.
Implementations
Sourceimpl PreSpawned
impl PreSpawned
Sourcepub fn new(hash: u64) -> PreSpawned
pub fn new(hash: u64) -> PreSpawned
You specify the hash yourself, default hasher not used.
Sourcepub fn default_with_salt(salt: u64) -> PreSpawned
pub fn default_with_salt(salt: u64) -> PreSpawned
Uses default hasher with additional salt.
pub fn for_receiver(self, entity: Entity) -> PreSpawned
impl PreSpawned
Hook calculates the hash (if missing), and updates the PreSpawned component. Since this is a hook, it will calculate based on components inserted before or alongside the PreSpawned component, on the same tick that PreSpawned was inserted.