pub struct PriorityConfig {
pub bandwidth_quota: Quota,
pub enabled: bool,
}Fields
bandwidth_quota: QuotaNumber of bytes per second that can be sent to each client
enabled: boolIf false, there is no bandwidth cap and all messages are sent as soon as possible
Implementations
Sourceimpl PriorityConfig
impl PriorityConfig
pub fn new(bytes_per_second_quota: u32) -> PriorityConfig