pub type Replicate = ReplicationTarget<()>;Available on crate feature
replication only.Expand description
Insert this component to start replicating your entity.
Remove it to pause sending replication updates. If you want to despawn an entity without the despawn getting replicated; you need to first remove this component before despawning the entity.
Aliased Type
pub struct Replicate { /* private fields */ }