pub struct SessionConfig {Show 18 fields
pub fake_packet_loss_send: f32,
pub fake_packet_loss_recv: f32,
pub fake_packet_lag_send: Duration,
pub fake_packet_lag_recv: Duration,
pub fake_packet_reorder_send: f32,
pub fake_packet_reorder_recv: f32,
pub fake_packet_reorder_time: Duration,
pub fake_packet_dup_send: f32,
pub fake_packet_dup_recv: f32,
pub fake_packet_dup_time_max: Duration,
pub timeout_initial: Duration,
pub timeout_connected: Duration,
pub send_buffer_size: usize,
pub send_rate_min: usize,
pub send_rate_max: usize,
pub mtu_packet_size: usize,
pub symmetric_connect: bool,
pub local_virtual_port: i32,
}Available on crate feature
steam only.Expand description
(CURRENTLY BROKEN) Configuration for establishing a Steam networking session.
Default values are obtained from steamnetworkingsockets.cpp.
Currently Broken
Due to steamworks-rs #169, these configuration options currently do nothing. If you attempt to re-enable the functionality and make a non-empty vector of config entries, you will always receive an invalid handle and run into a Steam error.
Fields
fake_packet_loss_send: f32fake_packet_loss_recv: f32fake_packet_lag_send: Durationfake_packet_lag_recv: Durationfake_packet_reorder_send: f32fake_packet_reorder_recv: f32fake_packet_reorder_time: Durationfake_packet_dup_send: f32fake_packet_dup_recv: f32fake_packet_dup_time_max: Durationtimeout_initial: Durationtimeout_connected: Durationsend_buffer_size: usizesend_rate_min: usizesend_rate_max: usizemtu_packet_size: usizesymmetric_connect: boollocal_virtual_port: i32Implementations
Sourceimpl SessionConfig
impl SessionConfig
Sourcepub fn to_options(&self) -> Vec<NetworkingConfigEntry>
pub fn to_options(&self) -> Vec<NetworkingConfigEntry>
Converts this to a Vec<NetworkingConfigEntry> for use in creating a
session.