get_component_unchecked

Function get_component_unchecked 

pub unsafe fn get_component_unchecked<'w>(
    unsafe_world_cell: UnsafeWorldCell<'w>,
    entity: &'w ArchetypeEntity,
    table_id: TableId,
    storage: StorageType,
    component_id: ComponentId,
) -> Ptr<'w>
Extracts a component as Ptr and its ticks from a table or sparse set, depending on its storage type.

Safety

The component must be present in this archetype, have the specified storage type and we must have read access to it.