EchConfig

Struct EchConfig 

pub struct EchConfig { /* private fields */ }
Available on crate feature websocket only.
Configuration for performing encrypted client hello.

Note: differs from the protocol-encoded EchConfig (EchConfigMsg).

Implementations

Source

impl EchConfig

pub fn new( ech_config_list: EchConfigListBytes<'_>, hpke_suites: &[&'static dyn Hpke], ) -> Result<EchConfig, Error>

Construct an EchConfig by selecting a ECH config from the provided bytes that is compatible with one of the given HPKE suites.

The config list bytes should be sourced from a DNS-over-HTTPS lookup resolving the HTTPS resource record for the host name of the server you wish to connect via ECH, and extracting the ECH configuration from the ech parameter. The extracted bytes should be base64 decoded to yield the EchConfigListBytes you provide to rustls.

One of the provided ECH configurations must be compatible with the HPKE provider’s supported suites or an error will be returned.

See the ech-client.rs example for a complete example of fetching ECH configs from DNS.