pub struct WebSocketRuntime { /* private fields */ }websocket only.Expand description
Provides a platform-agnostic way to spawn futures for driving the WebSocket IO layer.
Using WebSocket sessions requires spawning tasks on an async runtime. However, which runtime to use exactly, and how that runtime is provided, is target-dependent. This resource exists to provide a platform-agnostic way of spawning these tasks.
Platforms
Native
On a native target, this holds a handle to a tokio runtime, because
tokio-tungstenite only supports this async runtime.
Use the Default impl to create and leak a new tokio runtime, and use
that as the WebSocketRuntime handle.
If you already have a runtime handle, you can use
WebSocketRuntime::from(handle) to create a runtime from that handle.
WASM
On a WASM target, this uses wasm-bindgen-futures to spawn the future via
wasm-bindgen.
Use the Default impl to create a new WebSocketRuntime on WASM.
Implementations
Sourceimpl WebSocketRuntime
impl WebSocketRuntime
Sourcepub fn spawn_on_self<F>(&self, future: F)
pub fn spawn_on_self<F>(&self, future: F)
Spawns a future on the task runtime self.
If you are already in a task context, use the spawn function on your
platform (i.e. tokio::spawn) to avoid having to pass around
WebSocketRuntime.