pub struct InputBuffer<S, M> {
pub start_tick: Option<Tick>,
pub buffer: VecDeque<Compressed<S>>,
pub last_remote_tick: Option<Tick>,
pub marker: PhantomData<M>,
}input_bei or input_native or leafwing only.Expand description
Buffer that stores a value (usually Inputs) for the last few ticks.
S is the type of the InputSnapshot. M is present in case the InputSnapshot does not have a generic.
Fields
start_tick: Option<Tick>buffer: VecDeque<Compressed<S>>last_remote_tick: Option<Tick>For remote inputs, keep track of the last tick we have received from the remote. (this is necessary because even without receiving a remote tick we keep updating the buffer with predicted inputs)
marker: PhantomData<M>Implementations
Sourceimpl<T, M> InputBuffer<T, M>
impl<T, M> InputBuffer<T, M>
Sourcepub fn len(&self) -> usize
Available on crate feature input_native only.
pub fn len(&self) -> usize
input_native only.Number of elements in the buffer
Sourcepub fn clip_after(&mut self, tick: Tick)
Available on crate feature input_native only.
pub fn clip_after(&mut self, tick: Tick)
input_native only.Remove all elements in the buffer that are strictly after tick
(leaves tick in the buffer)
Sourcepub fn extend_to_range(&mut self, start_tick: Tick, end_tick: Tick)
Available on crate feature input_native only.
pub fn extend_to_range(&mut self, start_tick: Tick, end_tick: Tick)
input_native only.Make sure that the buffer fits the range [start_tick, end_tick]
This is used when we receive a new InputMessage, to update the buffer from the message.
It is important to extend the range, otherwise get_raw might return immediately if the tick is outside the current range.
Sourcepub fn set(&mut self, tick: Tick, value: T)
Available on crate feature input_native only.
pub fn set(&mut self, tick: Tick, value: T)
input_native only.Set the ActionState for the given tick in the InputBuffer
This should be called every tick.
Sourcepub fn set_empty(&mut self, tick: Tick)
Available on crate feature input_native only.
pub fn set_empty(&mut self, tick: Tick)
input_native only.Set the ActionState for the given tick in the InputBuffer
This should be called every tick.
pub fn set_raw(&mut self, tick: Tick, value: Compressed<T>)
input_native only.Sourcepub fn pop_keeping_last(&mut self, tick: Tick) -> Option<T>
Available on crate feature input_native only.
pub fn pop_keeping_last(&mut self, tick: Tick) -> Option<T>
input_native only.Like pop, but preserves the most recent entry so it
remains available as a get_predict fallback.
Sourcepub fn pop(&mut self, tick: Tick) -> Option<T>
Available on crate feature input_native only.
pub fn pop(&mut self, tick: Tick) -> Option<T>
input_native only.Remove all the inputs that are older or equal than the given tick, then return the input for the given tick
Sourcepub fn get_raw(&self, tick: Tick) -> &Compressed<T>
Available on crate feature input_native only.
pub fn get_raw(&self, tick: Tick) -> &Compressed<T>
input_native only.Get the raw InputData for the given tick, without resolving SameAsPrecedent
Sourcepub fn get(&self, tick: Tick) -> Option<&T>
Available on crate feature input_native only.
pub fn get(&self, tick: Tick) -> Option<&T>
input_native only.Get the ActionState for the given tick. This does not apply prediction:
- if the tick is outside the range of the buffer, it returns None
Sourcepub fn get_predict(&self, tick: Tick) -> Option<&T>
Available on crate feature input_native only.
pub fn get_predict(&self, tick: Tick) -> Option<&T>
input_native only.Get the ActionState for the given tick.
This applies prediction:
- if the tick is outside the range of the buffer, we return the last known ActionState (if any)
Sourcepub fn get_last(&self) -> Option<&T>
Available on crate feature input_native only.
pub fn get_last(&self) -> Option<&T>
input_native only.Get latest ActionState present in the buffer
Sourcepub fn get_last_with_tick(&self) -> Option<(Tick, &T)>
Available on crate feature input_native only.
pub fn get_last_with_tick(&self) -> Option<(Tick, &T)>
input_native only.Get latest ActionState present in the buffer, along with the associated Tick