Modules
Structs
- Link
- Transport-neutral byte stream between two peers.
- Link
Conditioner - Generic receive-side packet conditioner.
- LinkMtu
- The minimum and currently available maximum payload size of a link.
- Link
Plugin - Bevy plugin that installs link lifecycle and receive-buffer systems.
- Link
Receiver - Receive-side payload queue for a
Link. - Link
Sender - Send-side payload queue for a
Link. - Link
Start - Entity event requesting that a transport start establishing a
Link. - Link
Stats - Transport-observed statistics for a
Link. - Linked
- Marker component for an established link.
- Linking
- Marker component for a link whose transport connection is being established.
- MtuToo
Small - Error returned when a current MTU is smaller than a link’s stable minimum MTU.
- Unlink
- Entity event requesting that a transport terminate a
Link. - Unlinked
- Marker component for a link that is not connected.
Enums
- Link
Receive Systems - System sets that make up
LinkSystems::Receive. - Link
State - Current lifecycle state of a
Link. - Link
Systems - System sets for
Link-related operations. - Unlink
Reason - Why a
Linkwas unlinked viaUnlinkorUnlinked.
Constants
- DEFAULT_
MTU - Conservative default maximum payload size for a link.
Functions
- recv_
payload_ from_ bytes - Converts an immutable transport payload into Lightyear’s mutable receive payload.
Type Aliases
- Link
Receive Set Deprecated - Deprecated alias for
LinkReceiveSystems. - LinkSet
Deprecated - Deprecated alias for
LinkSystems. - Recv
Link Conditioner - Packet conditioner used for inbound
RecvPayloadvalues. - Recv
Payload - Mutable byte payload received from a transport.
- Send
Payload - Opaque byte payload queued for a transport to send.