pub trait SyncComponent:
Component<Mutability = Mutable>
+ Clone
+ PartialEq
+ Debug { }Available on crate feature
prediction only.Expand description
Trait for components that can be synchronized between a confirmed entity and its predicted/interpolated counterpart.
This is a marker trait, requiring Component<Mutability=Mutable> + Clone + PartialEq.
Components implementing this trait can have their state managed by the prediction and interpolation systems
according to the specified PredictionMode.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.