pub struct InputTimeline(pub Timeline<InputTimelineConfig>);client only.Expand description
Timeline that is used to keep track of when the client should buffer inputs.
This timeline is synced with the server timeline, and is the main driving timeline:
any speed adjustments applied to this timeline will also be applied to the Time<Virtual> timeline.
(and will therefore affect how fast the FixedUpdate loop runs, and how ticks are incremented)
This timeline is updated in PostUpdate; it CANNOT be used to get accurate tick in PreUpdate or Update;
use LocalTimeline instead.
Tuple Fields
0: Timeline<InputTimelineConfig>Trait Implementations
Sourceimpl Component for InputTimeline
impl Component for InputTimeline
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
Sourcetype Mutability = Mutable
type Mutability = Mutable
Component<Mutability = Mutable>,
while immutable components will instead have Component<Mutability = Immutable>. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<InputTimeline>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<InputTimeline>>
ComponentRelationshipAccessor required for working with relationships in dynamic contexts. Read moreSourcefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_replace() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_replace() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
EntityMapper. This is used to remap entities in contexts like scenes and entity cloning.
When deriving Component, this is populated by annotating fields containing entities with #[entities] Read moreSourceimpl Debug for InputTimeline
impl Debug for InputTimeline
Sourceimpl Default for InputTimeline
impl Default for InputTimeline
Sourcefn default() -> InputTimeline
fn default() -> InputTimeline
Sourceimpl Deref for InputTimeline
impl Deref for InputTimeline
Sourceimpl DerefMut for InputTimeline
impl DerefMut for InputTimeline
Sourceimpl FromReflect for InputTimeline
impl FromReflect for InputTimeline
Sourcefn from_reflect(
reflect: &(dyn PartialReflect + 'static),
) -> Option<InputTimeline>
fn from_reflect( reflect: &(dyn PartialReflect + 'static), ) -> Option<InputTimeline>
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetTypeRegistration for InputTimeline
impl GetTypeRegistration for InputTimeline
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Sourceimpl PartialReflect for InputTimeline
impl PartialReflect for InputTimeline
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn try_apply(
&mut self,
value: &(dyn PartialReflect + 'static),
) -> Result<(), ApplyError>
fn try_apply( &mut self, value: &(dyn PartialReflect + 'static), ) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Sourcefn reflect_owned(self: Box<InputTimeline>) -> ReflectOwned
fn reflect_owned(self: Box<InputTimeline>) -> ReflectOwned
Sourcefn try_into_reflect(
self: Box<InputTimeline>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<InputTimeline>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Sourcefn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
Sourcefn into_partial_reflect(self: Box<InputTimeline>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<InputTimeline>) -> Box<dyn PartialReflect>
Sourcefn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
Sourcefn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
Sourcefn reflect_partial_eq(
&self,
value: &(dyn PartialReflect + 'static),
) -> Option<bool>
fn reflect_partial_eq( &self, value: &(dyn PartialReflect + 'static), ) -> Option<bool>
Sourcefn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Self using reflection. Read moreSourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Sourcefn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
Sourcefn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
PartialReflect, combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
ReflectCloneError if the downcast fails. Read moreSourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Sourceimpl Reflect for InputTimeline
impl Reflect for InputTimeline
Sourcefn into_any(self: Box<InputTimeline>) -> Box<dyn Any>
fn into_any(self: Box<InputTimeline>) -> Box<dyn Any>
Box<dyn Any>. Read moreSourcefn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<InputTimeline>) -> Box<dyn Reflect>
fn into_reflect(self: Box<InputTimeline>) -> Box<dyn Reflect>
Sourcefn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Sourcefn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Sourceimpl SyncedTimeline for InputTimeline
impl SyncedTimeline for InputTimeline
Sourcefn sync_objective<T>(
&self,
remote: &T,
config: &<InputTimeline as NetworkTimeline>::Config,
ping_manager: &PingManager,
tick_duration: Duration,
) -> TickInstantwhere
T: SyncTargetTimeline,
fn sync_objective<T>(
&self,
remote: &T,
config: &<InputTimeline as NetworkTimeline>::Config,
ping_manager: &PingManager,
tick_duration: Duration,
) -> TickInstantwhere
T: SyncTargetTimeline,
We want the Predicted timeline to be:
- RTT/2 ahead of the server timeline, so that inputs sent from the server arrive on time
- On top of that, we will take a bit of margin based on the jitter
- we can reduce the ahead-delay by the input_delay
Because of the input-delay, the time we return might be in the past compared with the main timeline
Sourcefn sync<T>(
&mut self,
main: &T,
config: &<InputTimeline as NetworkTimeline>::Config,
ping_manager: &PingManager,
tick_duration: Duration,
) -> Option<i32>where
T: SyncTargetTimeline,
fn sync<T>(
&mut self,
main: &T,
config: &<InputTimeline as NetworkTimeline>::Config,
ping_manager: &PingManager,
tick_duration: Duration,
) -> Option<i32>where
T: SyncTargetTimeline,
Adjust the current timeline to stay in sync with the RemoteTimeline.
Most of the times this will just be slight nudges to modify the speed of the SyncedTimeline.
If there’s a big discrepancy, we will snap the SyncedTimeline to the RemoteTimeline by sending a SyncEvent
Sourcefn resync(&mut self, sync_objective: TickInstant) -> i32
fn resync(&mut self, sync_objective: TickInstant) -> i32
fn is_synced(&self) -> bool
Sourcefn relative_speed(&self) -> f32
fn relative_speed(&self) -> f32
f32.
A value of 1.0 means the timeline is running at normal speed.
A value of 0.5 means the timeline is running at half speed,fn set_relative_speed(&mut self, ratio: f32)
Sourceimpl TupleStruct for InputTimeline
impl TupleStruct for InputTimeline
Sourcefn field(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
fn field(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
index as a
&dyn Reflect.Sourcefn field_mut(
&mut self,
index: usize,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_mut( &mut self, index: usize, ) -> Option<&mut (dyn PartialReflect + 'static)>
index
as a &mut dyn Reflect.Sourcefn iter_fields(&self) -> TupleStructFieldIter<'_>
fn iter_fields(&self) -> TupleStructFieldIter<'_>
Sourcefn to_dynamic_tuple_struct(&self) -> DynamicTupleStruct
fn to_dynamic_tuple_struct(&self) -> DynamicTupleStruct
DynamicTupleStruct from this tuple struct.Sourcefn get_represented_tuple_struct_info(&self) -> Option<&'static TupleStructInfo>
fn get_represented_tuple_struct_info(&self) -> Option<&'static TupleStructInfo>
None if TypeInfo is not available.Sourceimpl TypePath for InputTimeline
impl TypePath for InputTimeline
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>