pub struct TicketRotator { /* private fields */ }Available on crate feature
std and crate feature websocket and (crate features hashbrown or std) only.Expand description
A ticketer that has a ‘current’ sub-ticketer and a single ‘previous’ ticketer. It creates a new ticketer every so often, demoting the current ticketer.
Implementations
Sourceimpl TicketRotator
impl TicketRotator
Sourcepub fn new(
lifetime: u32,
generator: fn() -> Result<Box<dyn ProducesTickets>, GetRandomFailed>,
) -> Result<TicketRotator, Error>
pub fn new( lifetime: u32, generator: fn() -> Result<Box<dyn ProducesTickets>, GetRandomFailed>, ) -> Result<TicketRotator, Error>
Creates a new TicketRotator, which rotates through sub-ticketers
based on the passage of time.
lifetime is in seconds, and is how long the current ticketer
is used to generate new tickets. Tickets are accepted for no
longer than twice this duration. generator produces a new
ProducesTickets implementation.