pub struct ComponentRegistration<'a, C> {
pub app: &'a mut App,
/* private fields */
}Available on crate feature
replication only.Fields
app: &'a mut AppImplementations
Sourceimpl<C> ComponentRegistration<'_, C>
impl<C> ComponentRegistration<'_, C>
pub fn new(app: &mut App) -> ComponentRegistration<'_, C>
Sourcepub fn add_map_entities(self) -> ComponentRegistration<'_, C>where
C: Clone + MapEntities + 'static,
pub fn add_map_entities(self) -> ComponentRegistration<'_, C>where
C: Clone + MapEntities + 'static,
Specify that the component contains entities which should be mapped from the remote world to the local world
upon deserialization using the component’s MapEntities implementation.
Sourcepub fn add_component_map_entities(self) -> ComponentRegistration<'_, C>
pub fn add_component_map_entities(self) -> ComponentRegistration<'_, C>
Similar to add_map_entities, but uses the Component::map_entities function instead of MapEntities::map_entities
pub fn with_replication_config( self, config: ComponentReplicationConfig, ) -> ComponentRegistration<'_, C>
Sourcepub fn add_delta_compression<Delta>(self) -> ComponentRegistration<'_, C>
pub fn add_delta_compression<Delta>(self) -> ComponentRegistration<'_, C>
Enable delta compression when serializing this component
Sourceimpl<C> ComponentRegistration<'_, C>where
C: Debug,
impl<C> ComponentRegistration<'_, C>where
C: Debug,
Sourcepub fn add_default_hash(self) -> ComponentRegistration<'_, C>
pub fn add_default_hash(self) -> ComponentRegistration<'_, C>
Add a hash function for this component using the core::hash::Hash trait implementation.
This will be used to compute a checksum for determinism checks.
Sourcepub fn add_custom_hash(
self,
f: fn(&C, &mut SeaHasher),
) -> ComponentRegistration<'_, C>where
C: Component,
pub fn add_custom_hash(
self,
f: fn(&C, &mut SeaHasher),
) -> ComponentRegistration<'_, C>where
C: Component,
Add a hash function for this component using the core::hash::Hash trait implementation.
This will be used to compute a checksum for determinism checks.