pub struct WebPkiServerVerifier { /* private fields */ }websocket only.Expand description
Default ServerCertVerifier, see the trait impl for more information.
Implementations
Sourceimpl WebPkiServerVerifier
impl WebPkiServerVerifier
Sourcepub fn builder(roots: Arc<RootCertStore>) -> ServerCertVerifierBuilder
pub fn builder(roots: Arc<RootCertStore>) -> ServerCertVerifierBuilder
Create a builder for the webpki server certificate verifier configuration using
the process-default CryptoProvider.
Server certificates will be verified using the trust anchors found in the provided roots.
Use Self::builder_with_provider if you wish to specify an explicit provider.
For more information, see the ServerCertVerifierBuilder documentation.
Sourcepub fn builder_with_provider(
roots: Arc<RootCertStore>,
provider: Arc<CryptoProvider>,
) -> ServerCertVerifierBuilder
pub fn builder_with_provider( roots: Arc<RootCertStore>, provider: Arc<CryptoProvider>, ) -> ServerCertVerifierBuilder
Create a builder for the webpki server certificate verifier configuration using
a specified CryptoProvider.
Server certificates will be verified using the trust anchors found in the provided roots.
The cryptography used comes from the specified CryptoProvider.
For more information, see the ServerCertVerifierBuilder documentation.